@@ -1,20 +1,14 @@
 package HTML::Video::Embed::Module;
-use Moose::Role;
+use Moo::Role;
 
 has 'domain_reg' => (
-    'is' => 'ro',
-    'isa' => 'RegexpRef',
+    'is' => 'lazy',
     'init_arg' => undef,
-    'lazy_build' => 1,
-    'lazy' => 1,
 );
 
 has 'validate_reg' => (
-    'is' => 'ro',
-    'isa' => 'RegexpRef',
+    'is' => 'lazy',
     'init_arg' => undef,
-    'lazy_build' => 1,
-    'lazy' => 1,
 );
 
 requires '_build_domain_reg';
